function E=calce1(net,A,T)
%CALCE1 Calculate network error for one time step.
%
%	CALCE1 is a core function called by higher level functions.
%	It is no recommended that you call CALCE1 directly since it
%	does not do any error checking.
%
%	E = CALCE1(NET,A,T)
%	  NET    - Neural network.
%	  A      - Layer outputs.
%	  T      - Layer targets.
%     Q      - Batch size.
%	Returns these signals:
%	  E      - Layer errors.
%
%	All signals (A, T, E) are passed in cell array form.
%	Each signal has TS cell array columns.

% Mark Beale, 11-31-97
% Copyright (c) 1992-1998 by The MathWorks, Inc.
% $Revision: 1.3 $

E = cell(net.numLayers,1);

for i=net.hint.targetInd;
  E{i} = T{i} - A{i};
end
